FELIX-790 - Display received date.

git-svn-id: https://svn.apache.org/repos/asf/felix/trunk@707587 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/webconsole/src/main/resources/res/ui/events.js b/webconsole/src/main/resources/res/ui/events.js
index 76c8655..82a7093 100644
--- a/webconsole/src/main/resources/res/ui/events.js
+++ b/webconsole/src/main/resources/res/ui/events.js
@@ -24,7 +24,8 @@
     document.write( "</tr>" );
 
     document.write( "<tr class='content'>" );
-    document.write( "<th class='content' width='20%'>Topic</th>" );
+    document.write( "<th class='content'>Received</th>" );
+    document.write( "<th class='content'>Topic</th>" );
     document.write( "<th class='content'>Properties</th>" );
     document.write( "</tr>" );
 
@@ -81,7 +82,8 @@
     var topic = dataEntry.topic;
     var properties = dataEntry.properties;
 
-    parent.appendChild( td( "content", { width: "20%"}, [ text( topic ) ] ) );
+    parent.appendChild( td( "content", null, [ text( new Date(dataEntry.received) ) ] ) );
+    parent.appendChild( td( "content", { "width": "20%", [ text( topic ) ] ) );
 
     var tableE = createElement("table");
     var bodyE = createElement("tbody");
@@ -100,8 +102,8 @@
 function renderEvents( /* Array of Data Objects */ bundleData )
 {
 
-    // topic and properties
-    var columns = 2;
+    // date, topic and properties
+    var columns = 3;
     
     header( columns );